@@ -1,5 +1,4 @@
 <?php
-// $Id: print.tpl.php,v 1.8.2.17 2010/08/18 00:33:34 jcnventura Exp $
 
 /**
  * @file
@@ -30,10 +29,7 @@
     <div class="print-breadcrumb"><?php print $print['breadcrumb']; ?></div>
     <hr class="print-hr" />
     <h1 class="print-title"><?php print $print['title']; ?></h1>
-    <div class="print-submitted"><?php print $print['submitted']; ?></div>
-    <div class="print-created"><?php print $print['created']; ?></div>
     <div class="print-content"><?php print $print['content']; ?></div>
-    <div class="print-taxonomy"><?php print $print['taxonomy']; ?></div>
     <div class="print-footer"><?php print $print['footer_message']; ?></div>
     <hr class="print-hr" />
     <div class="print-source_url"><?php print $print['source_url']; ?></div>
